@@ -10,11 +10,14 @@ use Test2::API qw{
 
 use Time::HiRes qw/time/;
 
-our $VERSION = '0.000119';
+our $VERSION = '0.000123';
 
+my $ADDED;
 sub import {
     my $start = time;
 
+    return if $ADDED++;
+
     test2_add_callback_exit(
         sub {
             my ($ctx, $real, $new) = @_;
